==> qieyun-examples-20220316.0.0.tgz: package/README.md <==
# qieyun-examples

JavaScript code examples to generate the derivatives of the Qieyun phonological system using qieyun-js

## Usage

```
https://nk2028-1305783649.file.myqcloud.com/qieyun-examples/<filename>
```

## List of included examples

**切韻音系拼音或轉寫 romanization/transcription of the Qieyun phonological system**

- 切韻拼音 (Tshet-uinh Phonetic Alphabet): `tshet.js`
- 白一平轉寫 (Baxter’s Transcription): `baxter.js`
- 有女羅馬字 (Blankego’s Romanization): `blankego.js`
- 古韻羅馬字 (Koxyonh’s Romanization): `kyonh.js`
- 隋拼 (Zyepheng): `zyepheng.js`

**切韻音系擬音 reconstruction of the Qieyun phonological system**

- 潘悟雲擬音 (Pan Wuyun's Reconstruction): `panwuyun.js`
- unt 切韻朗讀音 (unt’s Reading Pronunciation of Qieyun): `unt.js`
- unt 切韻擬音 J (unt’s Qieyun Reconstruction J): `unt_j.js`
- msoeg 中古拟音 V8 (msoeg’s Middle Chinese Reconstruction V8): `msoeg_v8.js`

**推導後世音系 extrapolated later phonological system**

- 推導盛中唐擬音 (Extrapolated Reconstruction of High and Middle Tang Chinese): `mid_tang.js`
- 推導《聲音唱和圖》擬音 (Extrapolated Reconstruction of _Shing-im Chiang-xhua Dhu_): `chiangxhua.js`
- 推導《分韻撮要》擬音 (Extrapolated Reconstruction of _Fan-Wan Ts'üt-Iú_): `fanwan.js`
- 推導普通話 (Extrapolated Putonghua): `putonghua.js`
- 推導廣州音 (Extrapolated Cantonese): `gwongzau.js`
- 推導上海話 (Extrapolated Shanghainese): `zaonhe.js`
- 推導南京話 (Extrapolated Nankinese): `langjin.js`
- 推導大埔話 (Extrapolated Taibu Hakka): `taibu.js`

**人造音系 artificial phonological system**

- 綾香思考音系 (Ayaka’s Phonological System for Thinking): `ayaka_v8.js`

==> qieyun-examples-20220407.0.0.tgz: package/README.md <==
# qieyun-examples

JavaScript code examples to generate the derivatives of the Qieyun phonological system using qieyun-js

## Usage

```
https://nk2028-1305783649.file.myqcloud.com/qieyun-examples/<filename>
```

## List of included examples

**切韻音系拼音或轉寫 romanization/transcription of the Qieyun phonological system**

- 切韻拼音 (Tshet-uinh Phonetic Alphabet): `tupa.js`（原 `tshet.js`）
- 白一平轉寫 (Baxter’s Transcription): `baxter.js`
- 有女羅馬字 (Blankego’s Romanization): `blankego.js`
- 古韻羅馬字 (Koxyonh’s Romanization): `kyonh.js`
- 隋拼 (Zyepheng): `zyepheng.js`

**切韻音系擬音 reconstruction of the Qieyun phonological system**

- 潘悟雲擬音 (Pan Wuyun's Reconstruction): `panwuyun.js`
- unt 切韻朗讀音 (unt’s Reading Pronunciation of Qieyun): `unt.js`
- unt 切韻擬音 J (unt’s Qieyun Reconstruction J): `unt_j.js`
- msoeg 中古拟音 V8 (msoeg’s Middle Chinese Reconstruction V8): `msoeg_v8.js`

**推導後世音系 extrapolated later phonological system**

- 推導盛中唐擬音 (Extrapolated Reconstruction of High and Middle Tang Chinese): `mid_tang.js`
- 推導《聲音唱和圖》擬音 (Extrapolated Reconstruction of _Shing-im Chiang-xhua Dhu_): `chiangxhua.js`
- 推導《分韻撮要》擬音 (Extrapolated Reconstruction of _Fan-Wan Ts'üt-Iú_): `fanwan.js`
- 推導普通話 (Extrapolated Putonghua): `putonghua.js`
- 推導廣州音 (Extrapolated Cantonese): `gwongzau.js`
- 推導上海話 (Extrapolated Shanghainese): `zaonhe.js`
- 推導南京話 (Extrapolated Nankinese): `langjin.js`
- 推導大埔話 (Extrapolated Taibu Hakka): `taibu.js`

**人造音系 artificial phonological system**

- 綾香思考音系 (Ayaka’s Phonological System for Thinking): `ayaka_v8.js`
